DurationField
=============

.. image:: https://api.travis-ci.org/johnpaulett/django-durationfield.png

Reusable application for a DurationField in Django.

See https://django-durationfield.readthedocs.org
